pyxmpp2.interfaces

Package pyxmpp2 :: Module interfaces |
[hide private]

# Module interfaces

Base interfaces of PyXMPP2.

Classes | [hide private]
| Resolver Abstract base class for asynchronous DNS resolvers to be used with PyxMPP.
| XMPPTransport Abstract base class for XMPP transport implementations.
| XMPPFeatureHandler Base class for objects handling incoming stanzas.
| StanzaPayload Abstract base class for stanza payload objects.
| StreamFeatureHandled Object returned by a stream feature handler for recognized and handled features.
| StreamFeatureNotHandled Object returned by a stream feature handler for recognized, but unhandled features.
| StreamFeatureHandler Base class for stream feature handlers.

Functions | [hide private]
_iq_handler(iq_type, payload_class, payload_key, usage_restriction) Method decorator generator for decorating <iq type='get'/> stanza handler methods in XMPPFeatureHandler subclasses. |
iq_get_stanza_handler(payload_class, payload_key=None, usage_restriction=`'``post-auth``'`) Method decorator generator for decorating <iq type='get'/> stanza handler methods in XMPPFeatureHandler subclasses. |
iq_set_stanza_handler(payload_class, payload_key=None, usage_restriction=`'``post-auth``'`) Method decorator generator for decorating <iq type='set'/> stanza handler methods in XMPPFeatureHandler subclasses. |
_stanza_handler(element_name, stanza_type, payload_class, payload_key, usage_restriction) Method decorator generator for decorating <message/> or <presence/> stanza handler methods in XMPPFeatureHandler subclasses. |
message_stanza_handler(stanza_type=None, payload_class=None, payload_key=None, usage_restriction=`'``post-auth``'`) Method decorator generator for decorating <message/> stanza handler methods in XMPPFeatureHandler subclasses. |
presence_stanza_handler(stanza_type=None, payload_class=None, payload_key=None, usage_restriction=`'``post-auth``'`) Method decorator generator for decorating <presence/> stanza handler methods in XMPPFeatureHandler subclasses. |
payload_element_name(element_name) Class decorator generator for decorationg StanzaPayload subclasses. |
stream_element_handler(element_name, usage_restriction=None) Method decorator generator for decorating stream element handler methods in StreamFeatureHandler subclasses. |

Function Details | [hide private]

### _iq_handler(iq_type, payload_class, payload_key, usage_restriction) |
Method decorator generator for decorating <iq type='get'/> stanza handler methods in XMPPFeatureHandler subclasses. Parameters: `payload_class` (subclass of StanzaPayload) - payload class expected `payload_key` - payload class specific filtering key `usage_restriction` (`unicode`) - optional usage restriction: "pre-auth" or "post-auth"

### iq_get_stanza_handler(payload_class, payload_key=None, usage_restriction=`'``post-auth``'`) |
Method decorator generator for decorating <iq type='get'/> stanza handler methods in XMPPFeatureHandler subclasses. Parameters: `payload_class` (subclass of StanzaPayload) - payload class expected `payload_key` - payload class specific filtering key `usage_restriction` (`unicode`) - optional usage restriction: "pre-auth" or "post-auth"

### iq_set_stanza_handler(payload_class, payload_key=None, usage_restriction=`'``post-auth``'`) |
Method decorator generator for decorating <iq type='set'/> stanza handler methods in XMPPFeatureHandler subclasses. Parameters: `payload_class` (subclass of StanzaPayload) - payload class expected `payload_key` - payload class specific filtering key `usage_restriction` (`unicode`) - optional usage restriction: "pre-auth" or "post-auth"

### _stanza_handler(element_name, stanza_type, payload_class, payload_key, usage_restriction) |
Method decorator generator for decorating <message/> or <presence/> stanza handler methods in XMPPFeatureHandler subclasses. Parameters: `element_name` (`unicode`) - "message" or "presence" `stanza_type` (`unicode`) - expected value of the 'type' attribute of the stanza `payload_class` (subclass of StanzaPayload) - payload class expected `payload_key` - payload class specific filtering key `usage_restriction` (`unicode`) - optional usage restriction: "pre-auth" or "post-auth"

### message_stanza_handler(stanza_type=None, payload_class=None, payload_key=None, usage_restriction=`'``post-auth``'`) |
Method decorator generator for decorating <message/> stanza handler methods in XMPPFeatureHandler subclasses. Parameters: `payload_class` (subclass of StanzaPayload) - payload class expected `stanza_type` (`unicode`) - expected value of the 'type' attribute of the stanza. `None` means all types except 'error' `payload_key` - payload class specific filtering key `usage_restriction` (`unicode`) - optional usage restriction: "pre-auth" or "post-auth"

### presence_stanza_handler(stanza_type=None, payload_class=None, payload_key=None, usage_restriction=`'``post-auth``'`) |
Method decorator generator for decorating <presence/> stanza handler methods in XMPPFeatureHandler subclasses. Parameters: `payload_class` (subclass of StanzaPayload) - payload class expected `stanza_type` (`unicode`) - expected value of the 'type' attribute of the stanza. `payload_key` - payload class specific filtering key `usage_restriction` (`unicode`) - optional usage restriction: "pre-auth" or "post-auth"

### payload_element_name(element_name) |
Class decorator generator for decorationg StanzaPayload subclasses. Parameters: `element_name` (`unicode`) - XML element qname handled by the class

### stream_element_handler(element_name, usage_restriction=None) |
Method decorator generator for decorating stream element handler methods in StreamFeatureHandler subclasses. Parameters: `element_name` (`unicode`) - stream element QName `usage_restriction` (`unicode`) - optional usage restriction: "initiator" or "receiver"